==> eslint-config-osedea-4.0.0.tgz: package/lib/rules/core-possible-errors.js <==
// ----------------------------------------------------------------------------
// Possible Errors
// ----------------------------------------------------------------------------

module.exports = {
    // enforce "for" loop update clause moving the counter in the right direction.
    'for-direction': 'error',

    // enforce return statements in getters
    'getter-return': 'error',

    // disallow using an async function as a Promise executor
    'no-async-promise-executor': 'error',

    // disallow await inside of loops
    'no-await-in-loop': 'error',

    // disallow comparing against -0
    'no-compare-neg-zero': 'error',

    // disallow assignment in conditional expressions
    'no-cond-assign': ['error', 'always'],

    // disallow use of `console` in the node environment
    'no-console': 'warn',

    // disallow use of constant expressions in conditions
    'no-constant-condition': 'error',

    // disallow control characters in regular expressions
    'no-control-regex': 'error',

    // disallow use of `debugger`
    'no-debugger': 'error',

    // disallow duplicate arguments in functions
    'no-dupe-args': 'error',

    // disallow duplicate keys when creating object literals
    'no-dupe-keys': 'error',

    // disallow a duplicate case label.
    'no-duplicate-case': 'error',

    // disallow the use of empty character classes in regular expressions
    'no-empty-character-class': 'error',

    // disallow empty statements
    'no-empty': ['error', { allowEmptyCatch: true }], // TODO

    // disallow assigning to the exception in a `catch` block
    'no-ex-assign': 'error',

    // disallow double-negation boolean casts in a boolean context
    'no-extra-boolean-cast': 'error', // TODO

    // disallow unnecessary parentheses
    'no-extra-parens': [
        // TODO
        'warn',
        'all',
        {
            conditionalAssign: false,
            returnAssign: false,
            nestedBinaryExpressions: false,
            ignoreJSX: 'multi-line',
            enforceForArrowConditionals: false,
        },
    ],

    // disallow unnecessary semicolons
    'no-extra-semi': 'error',

    // disallow overwriting functions written as function declarations
    'no-func-assign': 'error',

    // disallow function or variable declarations in nested blocks
    'no-inner-declarations': ['error', 'functions'], // TODO both

    // disallow invalid regular expression strings in the `RegExp` constructor
    'no-invalid-regexp': 'error',

    // disallow irregular whitespace outside of strings and comments
    'no-irregular-whitespace': 'error',

    // disallow characters which are made with multiple code points in character class syntax
    'no-misleading-character-class': 'error',

    // disallow the use of object properties of the global object (`Math` and `JSON`) as functions
    'no-obj-calls': 'error',

    // Disallow use of Object.prototypes builtins directly
    'no-prototype-builtins': 'off', // TODO

    // disallow multiple spaces in a regular expression literal
    'no-regex-spaces': 'error',

    // disallow sparse arrays
    'no-sparse-arrays': 'error',

    // disallow template literal placeholder syntax in regular strings
    'no-template-curly-in-string': 'error',

    // Avoid code that looks like two expressions but is actually one
    'no-unexpected-multiline': 'error', // TODO

    // disallow unreachable statements after a return, throw, continue, or break statement
    'no-unreachable': 'error',

    // disallow control flow statements in finally blocks
    'no-unsafe-finally': 'error',

    // disallow negating the left operand of relational operators
    'no-unsafe-negation': 'error',

    // disallow assignments that can lead to race conditions due to usage of await or yield
    'require-atomic-updates': 'error',

    // disallow comparisons with the value `NaN`
    'use-isnan': 'error',

    // Ensure that the results of typeof are compared against a valid string
    'valid-typeof': 'error', // TODO
};

==> eslint-config-osedea-6.2.0.tgz: package/lib/rules/core-possible-errors.js <==
// ----------------------------------------------------------------------------
// Possible Errors
// ----------------------------------------------------------------------------

const rules = {
    // enforce "for" loop update clause moving the counter in the right direction.
    'for-direction': 'error',

    // enforce return statements in getters
    'getter-return': 'error',

    // disallow using an async function as a Promise executor
    'no-async-promise-executor': 'error',

    // disallow await inside of loops
    'no-await-in-loop': 'error',

    // disallow comparing against -0
    'no-compare-neg-zero': 'error',

    // disallow assignment in conditional expressions
    'no-cond-assign': ['error', 'always'],

    // disallow use of `console` in the node environment
    'no-console': 'warn',

    // disallow use of constant expressions in conditions
    'no-constant-condition': 'error',

    // disallow control characters in regular expressions
    'no-control-regex': 'error',

    // disallow use of `debugger`
    'no-debugger': 'error',

    // disallow duplicate arguments in functions
    'no-dupe-args': 'error',

    // disallow duplicate conditions in if-else-if chains
    'no-dupe-else-if': 'error',

    // disallow duplicate keys when creating object literals
    'no-dupe-keys': 'error',

    // disallow a duplicate case label.
    'no-duplicate-case': 'error',

    // disallow the use of empty character classes in regular expressions
    'no-empty-character-class': 'error',

    // disallow empty statements
    'no-empty': ['error', { allowEmptyCatch: true }], // TODO

    // disallow assigning to the exception in a `catch` block
    'no-ex-assign': 'error',

    // disallow double-negation boolean casts in a boolean context
    'no-extra-boolean-cast': 'error', // TODO

    // disallow unnecessary parentheses
    // REF typescript
    'no-extra-parens': [
        // TODO
        'warn',
        'all',
        {
            conditionalAssign: true,
            returnAssign: false,
            nestedBinaryExpressions: false,
            ignoreJSX: 'multi-line',
            enforceForArrowConditionals: false,
            enforceForSequenceExpressions: true,
            enforceForNewInMemberExpressions: false,
        },
    ],

    // disallow unnecessary semicolons
    // REF typescript
    'no-extra-semi': 'error',

    // disallow overwriting functions written as function declarations
    'no-func-assign': 'error',

    // disallow assigning to imported bindings
    'no-import-assign': 'error',

    // disallow function or variable declarations in nested blocks
    'no-inner-declarations': ['error', 'functions'], // TODO both

    // disallow invalid regular expression strings in the `RegExp` constructor
    'no-invalid-regexp': 'error',

    // disallow irregular whitespace outside of strings and comments
    'no-irregular-whitespace': 'error',

    // disallow characters which are made with multiple code points in character class syntax
    'no-misleading-character-class': 'error',

    // disallow the use of object properties of the global object (`Math` and `JSON`) as functions
    'no-obj-calls': 'error',

    // Disallow use of Object.prototypes builtins directly
    'no-prototype-builtins': 'off', // TODO

    // disallow multiple spaces in a regular expression literal
    'no-regex-spaces': 'error',

    // disallow returning values from setters
    'no-setter-return': 'error',

    // disallow sparse arrays
    'no-sparse-arrays': 'error',

    // disallow template literal placeholder syntax in regular strings
    'no-template-curly-in-string': 'error',

    // Avoid code that looks like two expressions but is actually one
    'no-unexpected-multiline': 'error', // TODO

    // disallow unreachable statements after a return, throw, continue, or break statement
    'no-unreachable': 'error',

    // disallow control flow statements in finally blocks
    'no-unsafe-finally': 'error',

    // disallow negating the left operand of relational operators
    'no-unsafe-negation': ['error', { enforceForOrderingRelations: true }],

    // disallow assignments that can lead to race conditions due to usage of await or yield
    'require-atomic-updates': 'error',

    // disallow comparisons with the value `NaN`
    'use-isnan': ['error', { enforceForSwitchCase: true, enforceForIndexOf: true }],

    // Ensure that the results of typeof are compared against a valid string
    'valid-typeof': 'error', // TODO
};

module.exports = {
    rules,
};
